@@ -23,7 +23,8 @@
 #' @param pr_a_eps Numeric; shape parameter of inverse gamma prior for variance of data likelihood. default value is 0.001.
 #' @param pr_b_eps Numeric; scale parameter of inverse gamma prior for variance of data likelihood default value is 0.001.
 #' @param missing.val Numeric; a number to replace missing values. default value is 99.
-#'
+#' @param verbose Logical; If TRUE, MCMC samples are printed for each \code{nprint}. default value is FALSE 
+#' 
 #' @return \code{lsirm1pl_normal_fixed_gamma_mar} returns an object of  list containing the following components:
 #'  \item{data}{data frame or matrix containing the variables in the model.}
 #'  \item{missing.val}{a number to replace missing values.}
@@ -71,19 +72,19 @@ lsirm1pl_normal_fixed_gamma_mar = function(data, ndim = 2, niter = 15000, nburn
                                            jump_beta = 0.4, jump_theta = 1.0, jump_z = 0.5, jump_w = 0.5,
                                            pr_mean_beta = 0, pr_sd_beta = 1.0, pr_mean_theta = 0,
                                            pr_a_theta = 0.001, pr_b_theta = 0.001,
-                                           pr_a_eps = 0.001, pr_b_eps = 0.001, missing.val = 99){
+                                           pr_a_eps = 0.001, pr_b_eps = 0.001, missing.val = 99, verbose=FALSE){
 
   if(is.data.frame(data)){
     cname = colnames(data)
   }else{
     cname = paste("item", 1:ncol(data), sep=" ")
   }
-
+  cat("\n\nFitting with MCMC algorithm\n")
   output <- lsirm1pl_normal_fixed_gamma_mar_cpp(as.matrix(data),  ndim,  niter,  nburn,  nthin,  nprint,
                                                 jump_beta, jump_theta, jump_z, jump_w,
                                                 pr_mean_beta, pr_sd_beta, pr_mean_theta,
                                                 pr_a_theta, pr_b_theta,  pr_a_eps, pr_b_eps,
-                                                missing.val)
+                                                missing.val, verbose=verbose)
 
   mcmc.inf = list(nburn=nburn, niter=niter, nthin=nthin)
   nsample <- nrow(data)
@@ -96,7 +97,7 @@ lsirm1pl_normal_fixed_gamma_mar = function(data, ndim = 2, niter = 15000, nburn
   z.star = output$z[max.address,,]
   w.proc = array(0,dim=c(nmcmc,nitem,ndim))
   z.proc = array(0,dim=c(nmcmc,nsample,ndim))
-
+  cat("\n\nProcrustes Matching Analysis\n")
   for(iter in 1:nmcmc){
     z.iter = output$z[iter,,]
     if(iter != max.address) z.proc[iter,,] = procrustes(z.iter,z.star)$X.new
@@ -122,6 +123,7 @@ lsirm1pl_normal_fixed_gamma_mar = function(data, ndim = 2, niter = 15000, nburn
   rownames(beta.summary) <- cname
 
   # Calculate BIC
+  cat("\n\nCalculate BIC\n")
   missing_est = ifelse(imp.estimate > 0.5, 1, 0)
   data[data == missing.val] = missing_est
   log_like = log_likelihood_normal_cpp(as.matrix(data), ndim, as.matrix(beta.estimate), as.matrix(theta.estimate), 1, z.est, w.est, sigma.estimate, missing.val)
